SysInfo class abstract

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

cores List<CoreInfo>
Returns the information about the processors.
final
kernelArchitecture ProcessorArchitecture
Returns the architecture of the kernel by obtaining the rawKernelArchitecture and converting it to a high level ProcessorArchitecture.
final
kernelBitness int
Returns the bintness of kernel.
final
kernelName String
Returns the name of kernel.
final
kernelVersion String
Returns the version of kernel.
final
operatingSystemName String
Returns the name of operating system.
final
operatingSystemVersion String
Returns the version of operating system.
final
rawKernelArchitecture String
Returns the raw architecture of the kernel as reported by the OS
final
userDirectory String
Returns the path of user home directory.
final
userId String
Returns the identifier of current user.
final
userName String
Returns the name of current user.
final
userSpaceBitness int
Returns the bitness of the user space.
final

Static Methods

getAvailablePhysicalMemory() int
Returns the amount of available physical memory in bytes.
getFreePhysicalMemory() int
Returns the amount of free physical memory in bytes.
getFreeVirtualMemory() int
Returns the amount of free virtual memory in bytes.
getTotalPhysicalMemory() int
Returns the amount of total physical memory in bytes.
getTotalVirtualMemory() int
Returns the amount of total virtual memory in bytes.
getVirtualMemorySize() int
Returns the amount of virtual memory in bytes used by the proccess.